summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/enum.h
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/enum.h')
-rw-r--r--crawl-ref/source/enum.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/crawl-ref/source/enum.h b/crawl-ref/source/enum.h
index 4e4b8885f2..0d44153e1d 100644
--- a/crawl-ref/source/enum.h
+++ b/crawl-ref/source/enum.h
@@ -1287,8 +1287,9 @@ enum item_status_flag_type // per item flags: ie. ident status, cursed status
ISFLAG_NOTED_ID = 0x08000000,
ISFLAG_NOTED_GET = 0x10000000,
- ISFLAG_BEEN_IN_INV = 0x20000000, // Item has been in inventory
- ISFLAG_SUMMONED = 0x40000000 // Item generated on a summon
+ ISFLAG_BEEN_IN_INV = 0x20000000, // Item has been in inventory
+ ISFLAG_SUMMONED = 0x40000000, // Item generated on a summon
+ ISFLAG_DROPPED_BY_ALLY = 0x80000000 // Item was dropped by an ally
};
enum job_type